@@ -29,7 +29,6 @@ SPDX-License-Identifier: GPL-2.0-only
 #include <QTabWidget>
 #include <QWidget>
 
-#include "companylogo.h"
 #include "helpbrowser.h"
 
 //! The StartWidget class provides a lesson list and lesson settings.
@@ -198,7 +197,6 @@ private:
     QCheckBox* checkKeyBorder;
     QCheckBox* checkStatusInformation;
     QCheckBox* checkKeyPath;
-    CompanyLogo* companyLogo;
     QPushButton* buttonEditLesson;
     QWidget* tabTrainingLessons;
     QWidget* tabOpenLessons;
